@@ -23,7 +23,7 @@ class HttpMethodEnum(Enum):
     DELETE = 'DELETE'
 
 
-def invoke_http_request(endpoint, method, headers, payload=None, json_data=None, timeout=61):
+def invoke_http_request(endpoint, method, headers, payload=None, json_data=None, timeout=61, response_type="json"):
     """ here two exception block. one is for request exception and other is for json decoder exception.
     RequestException raise when some error occur in API response
     JSONDecodeError: sometimes we don't know our API response is in json format or not so, when we return
@@ -44,6 +44,9 @@ def invoke_http_request(endpoint, method, headers, payload=None, json_data=None,
         if method == HttpMethodEnum.DELETE.value:
             response = _request.delete(url=endpoint, data=payload, timeout=timeout)
         log_failed_http_request(endpoint, response.text, response.status_code)
+        if response_type != "json":
+            return response.text, response.status_code
+
         return response.json(), response.status_code
     except requests.exceptions.RequestException:
         print('Error raised while invoking %s', endpoint)
@@ -148,8 +151,14 @@ def chunks(lst, n):
 
 
 def buildquery(json_object):
+    """ This function can convert json form query to sql query. Note: Don't use single quotes ('') for input query"""
+
     if 'field' in json_object.keys():
         # In this case the json_object is an object which describes a single query
+        if json_object.get("operator") == 'IN':
+            value = json_object.get("value")
+            value = tuple(num for num in value.replace('(', '').replace(')', '').replace('...', '').split(', '))
+            return json_object.get("field") + " " + json_object.get("operator") + " " + str(value) + " "
         if json_object.get("operator") != 'BETWEEN':
             return json_object.get("field") + " " + json_object.get("operator") + " '" + json_object.get("value") + "' "
         else:
@@ -585,11 +594,12 @@ def invoke_set_value_task(conf, task_id, vtiger_access):
         print("set_value_configs not found in conf")
 
 
-def invoke_web_service_task(conf, task_id):
+def invoke_web_service_task(conf, task_id, response_type="json"):
     """ Web service task:
         params:
         1. conf: conf object
         2. task_id: current task id
+        3. response_type: response type of request
 
         Execution:
         1. get request object and rule from conf
@@ -617,11 +627,13 @@ def invoke_web_service_task(conf, task_id):
 
                 if payload:
                     if headers.get('content-type', '') == 'application/json':
-                        response, status = invoke_http_request(url, request_type, headers, json_data=payload)
+                        response, status = invoke_http_request(url, request_type, headers, json_data=payload,
+                                                               response_type=response_type)
                     else:
-                        response, status = invoke_http_request(url, request_type, headers, payload=payload)
+                        response, status = invoke_http_request(url, request_type, headers, payload=payload,
+                                                               response_type=response_type)
                 else:
-                    response, status = invoke_http_request(url, request_type, headers)
+                    response, status = invoke_http_request(url, request_type, headers, response_type=response_type)
                 if is_success_request(status):
                     return response
         else:
